/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.util.swing;

import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;

/**
 * Boilerplate for document listeners using the same handling for all update types.
 * 
 * @author johan
 */
public abstract class UnifiedDocumentListener implements DocumentListener {

    @Override
    public void insertUpdate(DocumentEvent de) {
        handleUpdate(de);
    }

    @Override
    public void removeUpdate(DocumentEvent de) {
        handleUpdate(de);
    }

    @Override
    public void changedUpdate(DocumentEvent de) {
        handleUpdate(de);
    }

    /**
     * Handle any type of update.
     * E.g. show validation feedback, update dependent components, ...
     */
    protected abstract void handleUpdate(DocumentEvent de);
}
