/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.util.swing.beanbinding;

import org.jdesktop.beansbinding.Validator;
import org.openide.util.NbBundle;

/**
 * <p>Validator for Double</p> 
 * 
 * <p>Checks if the value passed is {@link Double#MIN_VALUE}<br/> 
 * this indicates an error occurred trying to convert user input to value<br/>
 * Use the {@link DoubleConverter} to get this functionality</p>
 * 
 * <p>
 * Usage:<br/>
 * 
 * yourBinding.setConverter(new {@link DoubleConverter}());<br/>
 * yourBinding.setValidator(new {@link DoubleValidator}());
 * </p>
 * 
 *
 * @author Merijn Zengers
 */
@NbBundle.Messages("DoubleValidator invalid number message=Value should be a number")
public class DoubleValidator extends Validator<Double> {

        @Override
        public Validator.Result validate(Double arg) {
            if (arg == Double.MIN_VALUE) {
                return new Validator.Result(null, Bundle.DoubleValidator_invalid_number_message());
            }
            return null;
        }
    }